@@ -18,7 +18,7 @@ _dothis_completions()
 
     COMPREPLY=($(compgen -W "$(cd .tom && ls -1 *.pl6 | perl -n -e 'chomp; s{.pl6}{}; print "$_ " ')" -- ${cur_word} ))
 
-  elif perl -e '$w=$ENV{cur_word}; exit(0) unless $w; $w=~/-/ or exit 2'; then
+  elif perl -e '$w=$ENV{cur_word}; exit(0) unless $w; $w=~/^-+/ or exit 2'; then
 
 
     COMPREPLY=( $( compgen -W "--help --completion --last --profile --list --cat -q --quiet --verbose --lines" -- ${cur_word} ))
